.. _ydoc directive_3 directive_3_2 d322 d322b:

``d322b``
=========

Subdirective D 3.2.2b saves the result

Single-valued parameter:

  * ``filename``: name of file to save (default: flipfile.dat)



----

This page was automatically generated by **ycleptic** v1.8.0 on 2025-08-04.